<h1>DeathRay<img src='https://github.com/yngtodd/deathray/blob/master/img/snek.png' align='right' width='180' height='104'></h1>




[![Build Status](https://travis-ci.com/yngtodd/deathray.svg?branch=master)](https://travis-ci.com/yngtodd/deathray)
[![pypi](https://img.shields.io/pypi/v/deathray.svg)](https://pypi.python.org/pypi/deathray)


Anomaly Detection in an Astrophysics Simulation


* Free software: MIT license
* Documentation: https://deathray.readthedocs.io.


#### Features

DeathRay comes with a built in command line interface:

```python
python -m deathray.cli greet
```
